#### Please select the sections that you would like to print

Select All
Case Information
Party
Disposition Events
Events and Hearings
Financial
Print

# Case Information

19D78499 | HARVARD PLACE APARTMENTS VS JASMIN GOSIER,AND ALL OTHERS

Case Number
19D78499

Court
Division 0

Judicial Officer
Anderson, Berryl A

File Date
05/10/2019

Case Type
Magistrate Dispossessory - Non Payment of Rent

Case Status
Closed

# Party

Plaintiff
HARVARD PLACE APARTMENTS

Address

2210 SULLIVAN RD
COLLEGE PARK GA 30337

Active Attorneys

Lead Attorney
Scaljon, Michael W

Retained

Defendant
GOSIER, JASMIN

Address

6256 HILLANDALE DRIVE
910
LITHONIA GA 30058

Defendant
ALL OTHERS, AND

Address

6256 HILLANDALE DRIVE
910
LITHONIA GA 30058

# Disposition Events

05/31/2019 Judgment

Judicial Officer
Scott, Sabrina

Judgment Type
Writ Issued

06/03/2019 Judgment

Judgment Type
Dismissed without Prejudice

# Events and Hearings

- 05/10/2019 Dispossessory Warrant

  Comment
  Of the plaintiff

- 05/16/2019 Tack and Mail Service

  Comment
  Answer by 5/21/2019

- 05/29/2019 Writ application sent to judge

- 05/31/2019 Writ To Marshal

- 05/31/2019 Writ Service

  Served
  07/22/2019

  Anticipated Server
  Marshal

  Anticipated Method

- 07/22/2019 Writ called back from Marshal

Loading financial, please wait...